#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-PyVirtualDisplay%{psuffix}
Version:        3.0
Release:        4.1
Summary:        Python wrapper for Xvfb, Xephyr and Xvnc
License:        BSD-2-Clause
URL:            https://github.com/ponty/PyVirtualDisplay
Source:         https://files.pythonhosted.org/packages/source/P/PyVirtualDisplay/PyVirtualDisplay-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-EasyProcess
Requires:       xorg-x11-Xvfb
Suggests:       xorg-x11-Xvnc
Suggests:       xorg-x11-server-extra
BuildArch:      noarch
%if %{with test}
# SECTION test requirements
BuildRequires:  %{python_module PyVirtualDisplay}
BuildRequires:  %{python_module EasyProcess}
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module attrs}
BuildRequires:  %{python_module entrypoint2}
BuildRequires:  %{python_module psutil}
BuildRequires:  %{python_module pytest-xdist}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module vncdotool >= 0.13.0}
BuildRequires:  /usr/bin/who
BuildRequires:  xmessage
BuildRequires:  xorg-x11-server-extra
BuildRequires:  xvfb-run
# /SECTION
%endif
%python_subpackages

%description
PyVirtualDisplay is a python wrapper for Xvfb, Xephyr and Xvnc.

%prep
%setup -q -n PyVirtualDisplay-%{version}

%build
%python_build

%install
%if !%{with test}
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
donttest="examples or smart"
# This test fails sometimes because a race condition with threads
donttest+=" or test_disp_var"
%{python_expand #
export PYTHONPATH=%{buildroot}%{$python_sitelib}
xvfb-run --server-args "-screen 0 1920x1080x24" \
  $python -m pytest -v tests -rs -k "not ($donttest)" -n auto
}
%endif

%if !%{with test}
%files %{python_files}
%license LICENSE.txt
%doc README.md
%{python_sitelib}/pyvirtualdisplay
%{python_sitelib}/PyVirtualDisplay-%{version}-*info
%endif

%changelog
* Wed Sep  6 2023 Dirk Müller <dmueller@suse.com>
- require who to builld with coreutils-systemd split
* Sat Jun 10 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Wed Feb 22 2023 Daniel Garcia <daniel.garcia@suse.com>
- Disable broken test, test_disp_var
* Sat Nov 26 2022 Torsten Gruner <simmphonie@opensuse.org>
- Update to v3.0
  * no release notes
* Sat Oct 16 2021 Ben Greiner <code@bnavigator.de>
- Update to v2.2
  * no release notes
- Disable python2: not supported, not resolvable on Leaps
* Sat Mar 27 2021 Ben Greiner <code@bnavigator.de>
- Update to v2.1
  * no release notes
* Fri Aug 14 2020 John Vandenberg <jayvdb@gmail.com>
- Remove %%bcond_without test and activate test suite
- Update to v1.3.2
  * No changelog available
    See https://github.com/ponty/PyVirtualDisplay/compare/0.2.5...1.3.2
* Mon Mar  2 2020 Steve Kowalik <steven.kowalik@suse.com>
-  Update to 0.2.5:
  * No changelog available
* Thu Nov  7 2019 Matej Cepl <mcepl@suse.com>
- Run through spec-cleaner
* Tue Dec 18 2018 Matej Cepl <mcepl@suse.com>
- Also remove nonsensical dependency on python3-2to3
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Aug 28 2017 toddrme2178@gmail.com
- update to version 0.2.1:
  * no changelog available
- Implement single-spec version
- Fix source URL
* Tue May 12 2015 benoit.monin@gmx.fr
- update to version 0.1.5:
  * no changelog available
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Sun Feb 17 2013 p.drouand@gmail.com
- Update to version 0.1.1:
  * No changelog available
* Fri Jan 11 2013 p.drouand@gmail.com
- Initial python3 support
* Fri Jan 11 2013 p.drouand@gmail.com
- Update to 0.1.1 version:
  * bugfix for wx pyscreenshot backend
  * remove entrypoint2 dependency
* Mon Mar 26 2012 saschpe@suse.de
- Initial version
